import random
import json
import urllib3
import time

import temp_humidity
import led

COMMAND1 = "who are you"
COMMAND2 = "what can you do"
COMMAND3 = "temp"
COMMAND4 = "name an animal"
COMMAND5 = "get-ip"
COMMAND6 = "delayed_responses"

def blink_red():
    led.red_led(0)
    time.sleep(.5)
    led.red_led(1)
    time.sleep(1)
    led.red_led(0)

def blink_green(delay):
    led.green_led(1)
    time.sleep(delay)
    led.green_led(0)
    time.sleep(delay)


def mission_control(bot_id,output):
    for word in output['text'].split(" "):
        print(word)
        #led.red_led(1)
        if word.lower() == 'arm-1123':
            led.red_led(1)
            led.green_led(1)
        elif word.lower() == 'disarm':
            led.green_led(0)
            blink_red()
        elif word.lower() == 'pre-launch-sequence-1123':
            if led.GPIO.input(led.GREEN_LED):
                blink_green(1)
                led.red_led(1)
                blink_red()
                led.green_led(1)
            else:
                led.green_led(0)
                blink_red()
        elif word.lower() == 'launch-1123':
            if led.GPIO.input(led.GREEN_LED) and not led.GPIO.input(led.RED_LED):
                blink_green(.5)
                blink_green(.5)
                blink_green(.5)
                blink_green(.5)
                led.launch_led(1)
                time.sleep(3)
                led.launch_led(0)
            else:
                led.green_led(0)
                blink_red()

def handle_command(command):
    """
        Determine if the command is valid. If so, take action and return
        a response, if necessary.
    """
    response = ""
    if command.find(COMMAND1) >= 0:
        response = "I am a simpleton bot."
    elif command.find(COMMAND2) >= 0:
        response = "Not too much right now... waiting for students to teach me more."
    elif command.find(COMMAND3) >= 0:
        try:
            import socket
            s = socket.socket(socket.AF_INET,socket.SOCK_DGRAM)
            s.connect(("8.8.8.8",80))
            ip = s.getsockname()[0]

            temp_c,temp,humidity = temp_humidity.read_temp_humidity()
            response = "At my location (" + ip + ") , the temperature is " + str(temp) + " and the relative humidity is " + str(humidity)
        except:
            response = "At my location, there is a sensor malfunction."

    elif command.find(COMMAND4) >= 0:
        try:
            http = urllib3.PoolManager()
            animals = json.loads(http.request('GET','https://www.randomlists.com/data/animals.json').data.decode('utf-8'))['data']
            response = animals[random.randint(0,len(animals)-1)]
        except:
            response = "Cannot find animals."

    elif command.find(COMMAND5) >= 0:
        import socket
        s = socket.socket(socket.AF_INET,socket.SOCK_DGRAM)
        s.connect(("8.8.8.8",80))
        response = s.getsockname()[0]

    elif COMMAND6 in command:
        response = "Wait | for | it | ... || April Fools!"

            
        
    return response




# Put your commands here
COMMAND1 = "throw mud at me"
COMMAND2 = "pick it up and throw"
COMMAND3 = "then do water"
COMMAND4 = "try sharks then"
COMMAND5 = "pikachu"
#COMMAND6
#COMMAND7

# Your handling code goes in this function
def handle_command(command):
    """
        Determine if the command is valid. If so, take action and return
        a response, if necessary.
    """
    response = ""
    if command.find(COMMAND1) >= 0:
        response = "okay how"
    elif command.find(COMMAND2) >=0:
        response = "what does that mean"
    elif command.find(COMMAND3) >=0:       
        response = "water? WHAT IS THAT!?!?!"
    elif command.find(COMMAND4) >=0:       
        response = "WHAT IS MUD WATER AND SHARKS!?!?!?!?!?"
    elif command.find(COMMAND5) >=0:       
        response = "Oh its a pikachu? Wait WHAT IS A PIKACHU!?!?!?!?"

    return response
    
    



# Put your commands here
COMMAND1 = "what color is the sky?"

# Your handling code goes in this function
def handle_command(command):
    """
        Determine if the command is valid. If so, take action and return
        a response, if necessary.
    """
    response = ""
    if command.find(COMMAND1) >= 0:
        response = "It depends on who you are asking. I would say it is purple."
        
    return response




import RPi.GPIO as GPIO
import time

GREEN_LED = 16
RED_LED = 21
BLUE_LED = 20

GPIO.setmode(GPIO.BCM) #numbering scheme that corresponds to breakout board and pin layout
GPIO.setup(RED_LED,GPIO.OUT) #replace pinNum with whatever pin you used, this sets up that pin as an output
#set LED to flash forever

for i in range(10):
    # M
    GPIO.output(RED_LED,GPIO.HIGH)
    time.sleep(0.75)

    GPIO.output(RED_LED,GPIO.LOW)
    time.sleep(0.75)
    
    # E
    GPIO.output(RED_LED,GPIO.LOW)
    time.sleep(0.3)

    # R
    GPIO.output(RED_LED,GPIO.LOW)
    time.sleep(0.3)

    GPIO.output(RED_LED,GPIO.LOW)
    time.sleep(0.75)

    GPIO.output(RED_LED,GPIO.LOW)
    time.sleep(0.3)

    # R
    GPIO.output(RED_LED,GPIO.LOW)
    time.sleep(0.3)

    GPIO.output(RED_LED,GPIO.LOW)
    time.sleep(0.75)

    GPIO.output(RED_LED,GPIO.LOW)
    time.sleep(0.3)

    # Y
    GPIO.output(RED_LED,GPIO.LOW)
    time.sleep(0.75)

    GPIO.output(RED_LED,GPIO.LOW)
    time.sleep(0.3)

    GPIO.output(RED_LED,GPIO.LOW)
    time.sleep(0.75)

    GPIO.output(RED_LED,GPIO.LOW)
    time.sleep(0.75)
    



import os
import time

sensor = None

try:
    import Adafruit_DHT
    sensor = Adafruit_DHT.DHT22
except ImportError:
    pass

pin = 4

def read_temp_humidity():
	humidity, temperature = Adafruit_DHT.read_retry(sensor, pin)
	temp_f = temperature * 9.0 / 5.0 + 32.0
	return temperature, temp_f, humidity

def get_temp():
	humidity, temperature = Adafruit_DHT.read_retry(sensor,pin)
	temp_f = temperature * 9.0/5.0+32

	print temp_f
	print humidity
	return temp_f



import os
import sys
import time
from slackclient import SlackClient

import bot_id
import glob
import importlib

# Instructor and student imports
names_paths = glob.glob("./*/slacklib.py")
names_homeschool_paths = glob.glob("./homeschool/*/slacklib.py")
names_code_em_paths = glob.glob("./code_em/*/slacklib.py")
names = []
names_homeschool = []
names_code_em = []
for i in range(0, len(names_paths)):
    path = names_paths[i]
    path.lstrip("./")
    path.strip("/slacklib.py")
    names.append(path)
    
for i in range(0, len(names_homeschool_paths)):
    path = names_homeschool_paths[i]
    path.lstrip("./")
    path.strip("/slacklib.py")
    names.append(path)

for i in range(0, len(names_code_em_paths)):
    path = names_code_em_paths[i]
    path.lstrip("./")
    path.strip("/slacklib.py")
    names.append(path)

for i in range(0, len(names)):
    importlib.importmodule(i)
 
for i in range(0, len(names_homeschool)):
    importlib.importmodule(i)
       
for i in range(0, len(names_code_em)):
    importlib.importmodule(i)

# constants
try:
    AT_BOT = "@" + bot_id.get_id()
    CHANNEL = bot_id.get_group_id()
    print(CHANNEL)
except TypeError:
    pass

# instantiate client
slack_client = SlackClient(os.environ.get('SLACK_BOT_TOKEN'))


def handle_command(command, channel):
    """
        Receives commands directed at the bot and determines if they
        are valid commands. If so, then acts on the commands. If not,
        returns back what it needs for clarification.
        Need to determine an algorithm for student overloaded commands.
    """

    response = ''
    
    try:
        response = wray.handle_command(command)
        response += joe.handle_command(command)
        response += chris.handle_command(command)
        response += matthew.handle_command(command)
        response += homeschool.baron.handle_command(command)
        response += homeschool.elliot.handle_command(command)
        response += homeschool.kaleb.handle_command(command)
        response += homeschool.owen.handle_command(command)
        response += homeschool.vivian.handle_command(command)
        response += code_em.alec.handle_command(command)
        response += code_em.coy.handle_command(command)
        response += code_em.hadley.handle_command(command)
        response += code_em.qiuqiu.handle_command(command)
        response += code_em.zb.handle_command(command)
        response += code_em.aidan.handle_command(command)
        response += code_em.alex.handle_command(command)
        response += code_em.taixi.handle_command(command)
        response += code_em.al_kareem.handle_command(command)
        
    except:
        response += 'Unexpected Error.'

    print("["+response+"]")
    
    if len(response) == 0:
        response = "Why thank you, I don't know what else to say."

    # Split responses by %% and then add a delay in between
    # First test with separate postings, better approach will be
    # to use the chat.update command which will requires the ts back
    # from the orginial post.

    responses = response.split('%%')

    for response in responses:
    
        api_response = slack_client.api_call("chat.postMessage", channel=channel,
                                text=response, as_user=True)
        print(api_response)
        time.sleep(0.5)

def parse_slack_output(slack_rtm_output):
    """
        The Slack Real Time Messaging API is an events firehose.
        this parsing function returns None unless a message is
        directed at the Bot, based on its ID.
    """
    output_list = slack_rtm_output
    print(output_list)
    if output_list and len(output_list) > 0:
        for output in output_list:
            if output and 'text' in output and output['channel'] == CHANNEL:
                print("Entering Mission Control")
                #joe.slacklib.blink_green()
                wray.slacklib.mission_control(bot_id,output)

            if output and 'text' in output and AT_BOT in output['text']:
                # return text after the @ mention, whitespace removed
                return output['text'].split(AT_BOT)[1].strip().lower(), \
                       output['channel']
    return None, None

if __name__ == "__main__":
    READ_WEBSOCKET_DELAY = 1 # 1 second delay between reading from firehose
    if slack_client.rtm_connect():
        print("StarterBot connected and running!")
        while True:
            command, channel = parse_slack_output(slack_client.rtm_read())
            print(command,channel)
            if command and channel:
                handle_command(command, channel)
                
            time.sleep(READ_WEBSOCKET_DELAY)
    else:
        print("Connection failed. Invalid Slack token or bot ID?")






import unittest
import bot_id
import slackpi
import wray.slacklib
import chris.slacklib
import joe.slacklib
import matthew.slacklib
import homeschool.baron.slacklib
import homeschool.elliot.slacklib
import homeschool.kaleb.slacklib
import homeschool.owen.slacklib
import homeschool.vivian.slacklib
import code_em.alec.slacklib
import code_em.coy.slacklib
import code_em.hadley.slacklib
import code_em.qiuqiu.slacklib
import code_em.zb.slacklib
import code_em.aidan.slacklib
import code_em.alex.slacklib
import code_em.taixi.slacklib
import code_em.al_kareem.slacklib

class TestSlackBotFunctions(unittest.TestCase):

    def test_ci(self):
        self.assertTrue(True)

    def test_slack_client(self):
        self.assertTrue(bot_id.get_id() == None)

    def test_slack_pi(self):
        self.assertTrue(slackpi.handle_command("","") == None)

    def test_wray_handler(self):
        self.assertFalse(wray.slacklib.handle_command('') == None)
        self.assertTrue(len(wray.slacklib.handle_command(
            wray.slacklib.COMMAND1)) > 1)
        resp = wray.slacklib.handle_command(wray.slacklib.COMMAND4)
        print(resp)
        self.assertTrue(len(resp) > 1)

    def test_chris_handler(self):
        self.assertFalse(chris.slacklib.handle_command('') == None)
        self.assertTrue(len(chris.slacklib.handle_command(
            chris.slacklib.COMMAND1)) > 1)

    def test_joe_handler(self):
        self.assertFalse(joe.slacklib.handle_command('') == None)
        self.assertTrue(len(joe.slacklib.handle_command(
            joe.slacklib.COMMAND4)) > 1)
#        self.assertTrue(slackpi.handle_command(
#            joe.slacklib.COMMAND1,"") == None)
        #self.assertFalse(joe.slacklib.handle_command('green led on') == None)

    def test_matthew_handler(self):
        self.assertFalse(matthew.slacklib.handle_command('') == None)

        
    def test_baron_handler(self):
        self.assertFalse(homeschool.baron.slacklib.handle_command('') == None)
        self.assertTrue(len(homeschool.baron.slacklib.handle_command(
            homeschool.baron.slacklib.COMMAND1)) > 1)

    def test_elliot_handler(self):
        self.assertFalse(homeschool.elliot.slacklib.handle_command('') == None)
        self.assertTrue(len(homeschool.elliot.slacklib.handle_command(
            homeschool.elliot.slacklib.COMMAND1)) > 1)

    def test_kaleb_handler(self):
        self.assertFalse(homeschool.kaleb.slacklib.handle_command('') == None)
        self.assertTrue(len(homeschool.kaleb.slacklib.handle_command(
            homeschool.kaleb.slacklib.COMMAND1)) > 1)

    def test_owen_handler(self):
        self.assertFalse(homeschool.owen.slacklib.handle_command('') == None)
        self.assertTrue(len(homeschool.owen.slacklib.handle_command(
            homeschool.owen.slacklib.COMMAND1)) > 1)

    def test_vivian_handler(self):
        self.assertFalse(homeschool.vivian.slacklib.handle_command('') == None)
        self.assertTrue(len(homeschool.vivian.slacklib.handle_command(
            homeschool.vivian.slacklib.COMMAND1)) > 1)


    def test_alec_handler(self):
        self.assertFalse(code_em.alec.slacklib.handle_command('') == None)
        self.assertTrue(len(code_em.alec.slacklib.handle_command(
            code_em.alec.slacklib.COMMAND1)) > 1)

    def test_coy_handler(self):
        self.assertFalse(code_em.coy.slacklib.handle_command('') == None)
        self.assertTrue(len(code_em.coy.slacklib.handle_command(
            code_em.coy.slacklib.COMMAND1)) > 1)

    def test_hadley_handler(self):
        self.assertFalse(code_em.hadley.slacklib.handle_command('') == None)
        self.assertTrue(len(code_em.hadley.slacklib.handle_command(
            code_em.hadley.slacklib.COMMAND1)) > 1)

    def test_qiuqiu_handler(self):
        self.assertFalse(code_em.qiuqiu.slacklib.handle_command('') == None)
        self.assertTrue(len(code_em.qiuqiu.slacklib.handle_command(
            code_em.qiuqiu.slacklib.COMMAND1)) > 1)

    def test_zb_handler(self):
        self.assertFalse(code_em.zb.slacklib.handle_command('') == None)
        self.assertTrue(len(code_em.zb.slacklib.handle_command(
            code_em.zb.slacklib.COMMAND1)) > 1)

    def test_aidan_handler(self):
        self.assertFalse(code_em.aidan.slacklib.handle_command('') == None)
        self.assertTrue(len(code_em.aidan.slacklib.handle_command(
            code_em.aidan.slacklib.COMMAND1)) > 1)

    def test_alex_handler(self):
        self.assertFalse(code_em.alex.slacklib.handle_command('') == None)
        self.assertTrue(len(code_em.alex.slacklib.handle_command(
            code_em.alex.slacklib.COMMAND1)) > 1)

    def test_taixi_handler(self):
        self.assertFalse(code_em.taixi.slacklib.handle_command('') == None)
        self.assertTrue(len(code_em.taixi.slacklib.handle_command(
            code_em.taixi.slacklib.COMMAND1)) > 1)

    def test_al_kareem_handler(self):
        self.assertFalse(code_em.al_kareem.slacklib.handle_command('') == None)
        self.assertTrue(len(code_em.al_kareem.slacklib.handle_command(
            code_em.al_kareem.slacklib.COMMAND1)) > 1)

    # def test_new_command_handler(self):
    #     self.assertTrue(wray.slacklib.handle_command("new command: how are you?, i'm fine thank you") == 'ok')
    #     self.assertTrue(wray.slacklib.handle_command('how are you?') == "i'm fine thank you")
    #     self.assertTrue(wray.slacklib.handle_command('del command: how are you?') == 'ok')
    #     self.assertFalse(wray.slacklib.handle_command('what!') == None)


if __name__ == '__main__':
    unittest.main()



# Put your commands here
COMMAND1 = "hi"
COMMAND2 = "error..."

#Your handling code toes in this function
def handle_command(command):

    response = ""
    if command.find(COMMAND1) >= 0:
        response = "Oh hi there, Please input ERROR..."

    elif command.find(COMMAND2) >= 0:
        response = "ERROR..."
       #for i in range(5):
            #response = "ERROR..."
        
    return response




import os
from slackclient import SlackClient


BOT_NAME = 'sirexa'
CHANNEL_NAME = 'mission_control'

slack_client = SlackClient(os.environ.get('SLACK_BOT_TOKEN'))

def get_id():
    id = None
    api_call = slack_client.api_call("users.list")
    if api_call.get('ok'):
        # retrieve all users so we can find our bot
        users = api_call.get('members')
        for user in users:
            print(user.get('name'))
            if 'name' in user and user.get('name') == BOT_NAME:
                print("Bot ID for '" + user['name'] + "' is " + user.get('id'))
                id = user.get('id')
    else:
        print("could not find bot user with the name " + BOT_NAME)

    return id

def get_user_name(id):
    api_call = slack_client_api_call("users.info",user=id)
    if api_call.get('ok'):
        return api_call.get('user').get('name')

def get_channel_id():
    id = None
    api_call = slack_client.api_call("channels.list")
    if api_call.get('ok'):
        # retrieve all channels so we can find our channel
        channels = api_call.get('channels')
        for channel in channels:
            print(channel.get('name'))
            if 'name' in channel and channel.get('name') == CHANNEL_NAME:
                print("Channel ID for '" + CHANNEL_NAME + "' is " + channel.get('id'))
                id = channel.get('id')
    else:
        print("could not find channel user with the name " + CHANNEL_NAME)

    return id

def get_group_id():
    id = None
    api_call = slack_client.api_call("groups.list")
    if api_call.get('ok'):
        # retrieve all channels so we can find our channel
        channels = api_call.get('groups')
        for channel in channels:
            print(channel.get('name'))
            if 'name' in channel and channel.get('name') == CHANNEL_NAME:
                print("Channel ID for '" + CHANNEL_NAME + "' is " + channel.get('id'))
                id = channel.get('id')
    else:
        print("could not find channel user with the name " + CHANNEL_NAME)

    return id


def get_channel_name(id):
    api_call = slack_client_api_call("channels.info",channel=id)
    if api_call.get('ok'):
        return api_call.get('channel').get('name')



import time
import led
# Put your commands here
COMMAND1 = "are you awake?"
COMMAND2 = "what is your full name?"
COMMAND3 = "what is your favorite snack?"
COMMAND4 = "green led"
COMMAND5 = "red led"
COMMAND6 = "blue led"
COMMAND7 = "twitter syntax"
COMMAND8 = "explain sensor error"

def blink_green():
	for i in range(2):
		led.green_led(1)
		time.sleep(0.2)
		led.green_led(0)
		time.sleep(0.2)
        
# Your handling code goes in this function
def handle_command(command):
    """
        Determine if the command is valid. If so, take action and return
        a response, if necessary.
    """
    response = ""

    if command.find(COMMAND1) >= 0:
        response = "Just barely..."

    elif command.find(COMMAND2) >= 0:
        response = "Sirexa Watson Siri-Alexa."

    elif command.find(COMMAND3) >= 0:
        response = "electrons!"

    elif command.find(COMMAND4) >= 0:

        if command.find("on") >= 0:
            led.green_led(1)
            response = "ok"
        elif command.find("off") >= 0:
            led.green_led(0)
            response = "ok"
        else:
            response = "I'm not sure what to do with the green led."

    elif command.find(COMMAND5) >= 0:

        if command.find("on") >= 0:
            led.red_led(1)
            response = "ok"
        elif command.find("off") >= 0:
            led.red_led(0)
            response = "ok"
        else:
            response = "I'm not sure what to do with the red led."

    elif command.find(COMMAND6) >= 0:

        if command.find("on") >= 0:
            led.blue_led(1)
            response = "ok"
        elif command.find("off") >= 0:
            led.blue_led(0)
            response = "ok"
        else:
            response = "I'm not sure what to do with the blue led."

            
    elif command.find(COMMAND7) >= 0:
        response = "https://twitter.com/search?q=%40techemrva&src=typd"
	
    elif command.find(COMMAND8) >= 0:
        response = "Eric must have the room temperature set to 'Yuma Desert Mode'"
        
        
    return response




# Put your commands here
COMMAND1 = "~~"
COMMAND2 = "what is your name?"
COMMAND3 = "what is yor favorite color?"
COMMAND4 = "Purple"
COMMAND5 = "How old are you?"
COMMAND6 = "12"
COMMAND7 = "Hello"

# Your handling code goes in this function
def handle_command(command):
    """
        Determine if the command is valid. If so, take action and return
        a response, if necessary.
    """
    response = ""
    if command.find(COMMAND1) >= 0:
        response = "Huh?"

    elif command.find(COMMAND2) >= 0:
        response= "hi?"
    elif command.find(COMMAND3) >= 0:
        response= "how old are you?"
    elif command.find(COMMAND4) >= 0:
        response= "12"
    elif command.find(COMMAND5) >= 0:
        response= "what is your favorite color? mine is blue!"
    elif command.find(COMMAND6) >= 0:
        response= "cool"
    return response




import time

from setuptools import find_packages

from distutils.core import setup

patch_level = int(time.time())

ver = "0.2." + str(patch_level)[1:]

setup(
  name = 'slackbot_ce',
  packages = find_packages(),
  version = ver,
  description = 'Python Code for Tech Em Studios Create Em Class',
  author = 'Techem Studios',
  author_email = 'wray@techemstudios.com',
  url = 'https://github.com/wray/code_em',
  download_url = 'https://github.com/wray/code_em/tarball/'+ver,
  keywords = ['slackbot', 'RPi', 'AWS'],
  classifiers = [],
)



# Put your commands here
COMMAND1 = "what do i look like?"
COMMAND2 = "bluedibal"
COMMAND3 = "what is a computer"
COMMAND4 = "i don't like harry potter"
# Your handling code goes in this function
def handle_command(command):
    """
        Determine if the command is valid. If so, take action and return
        a response, if necessary.
    """
    response = ""
    if command.find(COMMAND1) >= 0:
        response = "does it look like i have eyes too you."
        
    elif command.find(COMMAND2) >= 0:
        response = "eniglesh plz."
        
    elif command.find(COMMAND3) >= 0:
        response = "you are using one."
    
    elif command.find(COMMAND4) >= 0:
        response = "you are wasting your life."

    return response





GREEN_LED = 16
RED_LED = 21
BLUE_LED = 20

try:
    import RPi.GPIO as GPIO
    GPIO.setmode(GPIO.BCM)
    GPIO.setup(GREEN_LED, GPIO.OUT)
    GPIO.setup(RED_LED, GPIO.OUT)
    GPIO.setup(BLUE_LED, GPIO.OUT)
    
except ImportError:
    pass

DEBUG = 1

def green_led(state):
    GPIO.output(GREEN_LED,state)


def red_led(state):
    GPIO.output(RED_LED,state)
        
def blue_led(state):
    GPIO.output(BLUE_LED,state)

def all_leds(state):
    green_led(state)
    red_led(state)
    blue_led(state)






# Put your commands here

COMMAND1 = "who is mr_techie"
COMMAND2 = "talk in binary"
COMMAND3 = "i dont like you"
COMMAND4 = "brit"
COMMAND5 = "hacker_life"

# Your handling code goes in this function
def handle_command(command):
    """
        Determine if the command is valid. If so, take action and return
        a response, if necessary.
    """

    response = ""
    if command.find(COMMAND1) >= 0:
        response = "I cannot reveal his identity."
    elif command.find(COMMAND2) >= 0:
        response = """01001001 00100000 01100110 01110101 01100011 01101011 0
        1101001 01101110 01100111 00100000 01101000 01100001 01110100 01100101
        00100000 01111001 01101111 01110101!!!"""
    elif command.find(COMMAND3) >= 0:
        response = "Well, I don't like you either!"
    elif command.find(COMMAND4) >= 0:
        response = "'Ello!'"
    elif command.find(COMMAND5) >= 0:
        response="""
        Hacking user @noobish_security...%%%%done.%%

        downloading fs...%%
        '/home' -- DONE%%
        '/bin' -- DONE%%
        '/usr' -- DONE%%%%%%
        '/etc' -- DONE%%%%
        '/boot' -- DONE %%

        searching for passwords...%%DONE
        this idiot does not have /etc/shadow...
        running 'john /etc/passwd'...%%%%%%%%%%DONE
        root password is 'password123' :%%
        running 'cat rootpass.txt | su -'
        waiting...%%%%DONE
        running script...
        ***Installing kernel-mode rootkit...%%%%%%DONE
        ***Regenerating intrd-2.64.img%%%%
        ***Creating hacked initramfs%%
        ***All done. Have a nice day :)"""

    return response
